@@ -1,22 +1,32 @@
+import importlib.resources
 import sys
+from functools import reduce
+from importlib import import_module
 from pathlib import Path
 
-import pkg_resources
+import importlib_metadata
 
 from oarepo_model_builder.builder import ModelBuilder
-from oarepo_model_builder.schema import ModelSchema
+from oarepo_model_builder.schema import ModelSchema, remove_star_keys
 from oarepo_model_builder.utils.hyphen_munch import HyphenMunch
 
 
-def create_builder_from_entrypoints(**kwargs):
-    output_classes = load_entry_points_list("oarepo_model_builder.outputs")
-    builder_classes = load_entry_points_list("oarepo_model_builder.builders")
-    preprocess_classes = load_entry_points_list("oarepo_model_builder.property_preprocessors")
-    model_preprocessor_classes = load_entry_points_list("oarepo_model_builder.model_preprocessors")
+def create_builder_from_entrypoints(profile="model", **kwargs):
+    # output classes do not depend on profile
+    output_classes = load_entry_points_list("oarepo_model_builder.outputs", None)
+    builder_classes = load_entry_points_list("oarepo_model_builder.builders", profile)
+    preprocess_classes = load_entry_points_list(
+        "oarepo_model_builder.property_preprocessors", profile
+    )
+    model_preprocessor_classes = load_entry_points_list(
+        "oarepo_model_builder.model_preprocessors", profile
+    )
 
     builder_types = [x.TYPE for x in builder_classes]
     output_builder_components = {
-        builder_type: load_entry_points_list(f"oarepo_model_builder.builder_components.{builder_type}")
+        builder_type: load_entry_points_list(
+            f"oarepo_model_builder.builder_components.{builder_type}", profile
+        )
         for builder_type in builder_types
     }
 
@@ -31,27 +41,57 @@ def create_builder_from_entrypoints(**kwargs):
 
 
 def load_entry_points_dict(name):
-    return {ep.name: ep.load() for ep in pkg_resources.iter_entry_points(group=name)}
+    return {
+        ep.name: ep.load()
+        for ep in importlib_metadata.entry_points().select(group=name)
+    }
 
 
-def load_entry_points_list(name):
-    ret = [(ep.name, ep.load()) for ep in pkg_resources.iter_entry_points(group=name)]
+def load_entry_points_list(name, profile):
+    ret = []
+    loaded = {}
+    group_name = f"{name}.{profile}" if profile else name
+    for ep in importlib_metadata.entry_points().select(group=group_name):
+        if ep.name in loaded:
+            print(
+                f"WARNING: Entry point {ep.name} has already been registered to group {name}. "
+                f"Previous value {loaded[ep.name]}, new ignored value {ep.value}"
+            )
+            continue
+        loaded_entry_point = ep.load()
+        ret.append((ep.name, loaded_entry_point))
+        loaded[ep.name] = ep.value
     ret.sort()
     return [x[1] for x in ret]
 
 
-def load_model_from_entrypoint(ep: pkg_resources.EntryPoint):
+def load_model_from_entrypoint(ep: importlib_metadata.EntryPoint):
     def load(schema):
-        filename = ".".join(ep.attrs)
-        data = pkg_resources.resource_string(ep.module_name, filename)
-        return schema._load(filename, content=data)
+        try:
+            loaded_schema = ep.load()
+        except:
+            module = import_module(ep.module)
+            split_attr = ep.attr.split(".")
+            fn = f"{split_attr[-2]}.{split_attr[-1]}"
+            if len(split_attr) > 2:
+                fn = reduce(lambda x, y: Path(x) / Path(y), split_attr[:-2]) / fn
+            module_path = getattr(module, "__path__", [])
+            if module_path:
+                full_fn = Path(module_path[0]) / fn
+            else:
+                full_fn = fn
+            content = importlib.resources.open_text(module, fn, encoding="utf-8").read()
+            loaded_schema = schema._load(full_fn, content=content)
+
+        remove_star_keys(loaded_schema)
+        return loaded_schema
 
     return load
 
 
 def load_included_models_from_entry_points():
     ret = {}
-    for ep in pkg_resources.iter_entry_points(group="oarepo.models"):
+    for ep in importlib_metadata.entry_points().select(group="oarepo.models"):
         ret[ep.name] = load_model_from_entrypoint(ep)
     return ret
 
@@ -65,6 +105,7 @@ def load_model(
     sets=(),
     model_content=None,
     extra_included=None,
+    merged_models=None,
 ):
     loaders = load_entry_points_dict("oarepo_model_builder.loaders")
     included_models = load_included_models_from_entry_points()
@@ -75,6 +116,7 @@ def load_model(
         content=model_content,
         loaders=loaders,
         included_models=included_models,
+        merged_models=merged_models,
     )
     for config in configs:
         load_config(schema, config, loaders)
