@@ -11,6 +11,7 @@ TEMPLATES = {
     "record-resource-config": "templates/invenio_record_resource_config.py.jinja2",
     "record-resource": "templates/invenio_record_resource.py.jinja2",
     "views": "templates/invenio_views.py.jinja2",
+    "invenio_version": "templates/invenio_version.py.jinja2",
     "config": "templates/invenio_config.py.jinja2",
     "ext": "templates/invenio_ext.py.jinja2",
     "proxies": "templates/invenio_proxies.py.jinja2",
@@ -18,8 +19,8 @@ TEMPLATES = {
     # utils and included
     "imports": "templates/imports.py.jinja2",
     # scripts
-    "script-bootstrap": "templates/script_bootstrap.sh.jinja2",
-    "script-runserver": "templates/script_runserver.sh.jinja2",
     "script-import-sample-data": "templates/script_import_sample_data.py.jinja2",
     "script-import-sample-data-shell": "templates/script_import_sample_data.sh.jinja2",
+    # cli
+    "cli": "templates/invenio_cli.py.jinja2",
 }
