@@ -1,7 +1,9 @@
+import json
 from typing import Callable, List
 
 import faker
 import faker.providers
+from faker import Faker
 from jinja2 import Environment, FunctionLoader
 
 from oarepo_model_builder.builders import OutputBuilder
@@ -35,11 +37,17 @@ class Provider:
         return rnd / 10
 
     def sample_object(self):
-        return {self.generator.word(): self.generator.word() for _ in range(self.generator.random.randrange(1, 5, 1))}
+        return {
+            self.generator.word(): self.generator.word()
+            for _ in range(self.generator.random.randrange(1, 5, 1))
+        }
 
     def constant(self, value=None):
         return value
 
+    def language_dict(self):
+        return {lang: Faker(locale=lang).sentence() for lang in ("cs", "en")}
+
 
 SKIP = "skip"
 
@@ -50,7 +58,9 @@ class InvenioScriptSampleDataBuilder(JSONBaseBuilder):
     output_file_name = "script-import-sample-data"
     parent_module_root_name = "jsonschemas"
 
-    def __init__(self, builder: ModelBuilder, property_preprocessors: List[PropertyPreprocessor]):
+    def __init__(
+        self, builder: ModelBuilder, property_preprocessors: List[PropertyPreprocessor]
+    ):
         super().__init__(builder, property_preprocessors)
         self.generator = SampleDataGenerator()
         from faker.config import PROVIDERS
@@ -63,9 +73,9 @@ class InvenioScriptSampleDataBuilder(JSONBaseBuilder):
             ],
         )
 
-        self.sample_data_providers = load_entry_points_list("oarepo_model_builder.sample_data_providers") + [
-            faker_provider
-        ]
+        self.sample_data_providers = load_entry_points_list(
+            "oarepo_model_builder.sample_data_providers", profile=None
+        ) + [faker_provider]
 
     @process("/model/**", condition=lambda current, stack: stack.schema_valid)
     def model_element(self):
@@ -92,6 +102,15 @@ class InvenioScriptSampleDataBuilder(JSONBaseBuilder):
             elif "items" in self.stack.top.data:
                 self.output.enter(key, [])
                 self.build_children()
+                top = self.output.stack.real_top
+
+                # make items unique, just for sure
+                top_as_dict = {}
+                for t in top:
+                    top_as_dict[json.dumps(t, sort_keys=True)] = t
+                top.clear()
+                top.extend(top_as_dict.values())
+
                 self.output.leave()
             else:
                 self.output.primitive(key, self.generate_fake(self.stack))
@@ -134,8 +153,14 @@ def get_oarepo_sample(stack):
         if isinstance(sample, str):
             return {"faker": "constant", "params": {"value": sample}}
         if isinstance(sample, (list, dict)):
-            if stack.top.schema_element_type == "property" and "items" in stack.top.data:
-                return {"faker": "random_elements", "params": {"elements": sample, "unique": True}}
+            if (
+                stack.top.schema_element_type == "property"
+                and "items" in stack.top.data
+            ):
+                return {
+                    "faker": "random_elements",
+                    "params": {"elements": sample, "unique": True},
+                }
             else:
                 return {"faker": "random_element", "params": {"elements": sample}}
 
@@ -170,17 +195,21 @@ def faker_provider(faker, settings, stack, params):
 
 
 class InvenioScriptSampleDataShellBuilder(OutputBuilder):
-    TYPE = "invenio_script_runserver"
+    TYPE = "invenio_script_sample_data_loader"
 
     def finish(self):
         context = {"settings": self.schema.settings}
 
         env = Environment(
-            loader=FunctionLoader(lambda tn: templates.get_template(tn, context["settings"])),
+            loader=FunctionLoader(
+                lambda tn: templates.get_template(tn, context["settings"])
+            ),
             autoescape=False,
         )
 
         ensure_directory(self.builder, "scripts")
         output = self.builder.get_output("diff", "scripts/load_sample_data.sh")
-        output.write(env.get_template("script-import-sample-data-shell").render(context))
+        output.write(
+            env.get_template("script-import-sample-data-shell").render(context)
+        )
         output.make_executable()
